@@ -12,47 +12,120 @@
  * SOFTWARE.
  */
 
-use {super::cli::Action, dmntk_common::Feelify, dmntk_feel::Scope};
+use {
+  super::cli::Action,
+  dmntk_common::{Feelify, Stringify},
+  dmntk_feel::Scope,
+};
 
 pub fn action() {
   match crate::cli::action() {
     Action::ParseDecisionTable(dtb_file_name) => {
-      //FIXME remove when implemented
-      print!("Parsing decision table from file: {}", dtb_file_name);
-      // parse_decision_table(&dtb_file_name);
+      // parses decision table from text file
+      parse_decision_table(&dtb_file_name);
     }
     Action::RecognizeDecisionTable(dtb_file_name) => {
-      //FIXME remove when implemented
-      print!("Recognizing decision table from file: {}", dtb_file_name);
-      // recognize_decision_table_from_file(&dtb_file_name);
+      // recognizes decision table loaded from text file
+      recognize_decision_table_from_file(&dtb_file_name);
     }
     Action::EvaluateDecisionTable(dtb_file_name, ctx_file_name) => {
-      //FIXME remove when implemented
-      print!("Evaluating decision table from files: {}, {}", dtb_file_name, ctx_file_name);
-      // evaluate_decision_table_from_file(dtb_file_name, ctx_file_name);
+      // evaluates decision table and context loaded from file
+      evaluate_decision_table_from_file(dtb_file_name, ctx_file_name);
     }
     Action::TestDecisionTable(dtb_file_name) => {
-      //FIXME remove when implemented
-      print!("Testing decision table from file: {}", dtb_file_name);
-      // test_decision_table_from_file(dtb_file_name);
+      // tests decision table loaded from file
+      test_decision_table_from_file(dtb_file_name);
     }
     Action::ParseFeelTextualExpression(feel_file_name, ctx_file_name) => {
+      // parses `FEEL` textual expression against the specified context
       parse_textual_expression_from_file(&feel_file_name, &ctx_file_name);
     }
     Action::EvaluateFeelTextualExpression(feel_file_name, ctx_file_name) => {
+      // evaluates `FEEL` textual expression against the specified context
       evaluate_textual_expression_from_file(&feel_file_name, &ctx_file_name);
     }
     Action::StartServer(server_config) => {
-      //FIXME remove when implemented
-      print!("Starting DMNTK server with configuration: {:?}", server_config);
-      // server::start(server_config)
+      // starts REST server
+      dmntk_server::start_server(server_config)
     }
     Action::NoAction => {
-      // do nothing
+      // does nothing
     }
   }
 }
 
+/// Parses decision table loaded from file.
+fn parse_decision_table(dtb_file_name: &str) {
+  match std::fs::read_to_string(dtb_file_name) {
+    Ok(text) => match dmntk_recognizer::scan(&text) {
+      Ok(mut canvas) => {
+        canvas.display_text_layer();
+        canvas.display_thin_layer();
+        canvas.display_body_layer();
+        canvas.display_grid_layer();
+        match canvas.plane() {
+          Ok(plane) => println!("PLANE\n{}", plane),
+          Err(reason) => println!("ERROR: {}", reason),
+        };
+      }
+      Err(reason) => println!("ERROR: {}", reason),
+    },
+    Err(reason) => println!("loading decision table file `{}` failed with reason: {}", dtb_file_name, reason),
+  }
+}
+
+/// Recognizes the decision table loaded from text file.
+fn recognize_decision_table_from_file(dtb_file_name: &str) {
+  match std::fs::read_to_string(dtb_file_name) {
+    Ok(ref text) => match dmntk_recognizer::Recognizer::recognize(&text) {
+      Ok(recognizer) => {
+        recognizer.trace();
+      }
+      Err(reason) => println!("ERROR: {}", reason),
+    },
+    Err(reason) => println!("loading decision table file `{}` failed with reason: {}", dtb_file_name, reason),
+  }
+}
+
+/// Evaluates context and decision table loaded from files.
+fn evaluate_decision_table_from_file(dtb_file_name: String, ctx_file_name: String) {
+  // read the context input from file
+  match std::fs::read_to_string(ctx_file_name.as_str()) {
+    Ok(ref context_input) => {
+      // read decision table input from file
+      match std::fs::read_to_string(dtb_file_name.as_str()) {
+        Ok(ref decision_table_input) => match dmntk_evaluator::evaluate_decision_table_and_context(decision_table_input, context_input) {
+          Ok(value) => {
+            println!("{}", value.stringify())
+          }
+          Err(reason) => println!("{}", reason),
+        },
+        Err(reason) => println!("loading decision table file `{}` failed with reason: {}", dtb_file_name, reason),
+      }
+    }
+    Err(reason) => println!("loading context file `{}` failed with reason: {}", ctx_file_name, reason),
+  }
+}
+
+/// Tests decision table loaded from file.
+fn test_decision_table_from_file(dtb_file_name: String) {
+  match std::fs::read_to_string(dtb_file_name.as_str()) {
+    Ok(dtb_input) => match dmntk_evaluator::evaluate_decision_table_and_test(&dtb_input, "%") {
+      Ok((result, expected, actual)) => {
+        if !result {
+          println!("FAILURE");
+          println!("Expected: {}", expected.stringify());
+          println!("  Actual: {}", actual.stringify());
+        } else {
+          println!("SUCCESS!");
+        }
+      }
+      Err(reason) => println!("{:?}", reason),
+    },
+    Err(reason) => println!("loading decision table file `{}` failed with reason: {}", dtb_file_name, reason),
+  }
+}
+
 /// Parses `FEEL` textual expression loaded from file and prints the parsed AST to standard output.
 fn parse_textual_expression_from_file(feel_file_name: &str, ctx_file_name: &str) {
   match std::fs::read_to_string(feel_file_name) {
